#
#  This file is part of Task::WebDyne::PAGI.
#
#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
#
#  This is free software; you can redistribute it and/or modify it under
#  the same terms as the Perl 5 programming language system itself.
#
#  Full license text is available at:
#
#  <http://dev.perl.org/licenses/>
#

package Task::WebDyne::PAGI;

use strict qw(vars);
use warnings;
use vars qw($VERSION $VERSION_GIT_SHA $AUTHORITY);


#  Version information
#
$AUTHORITY='cpan:ASPEER';
$VERSION='0.002';
chomp($VERSION_GIT_SHA=do { local (@ARGV, $/) = ($_=__FILE__.'.sha'); <> if -f $_ });


1;

__END__






=head1 NAME

Task::WebDyne::PAGI - Install PAGI dependencies for WebDyne


=head1 SYNOPSIS


 #  Using CPAN
 #
 cpan Task::WebDyne::PAGI
 
 
 #  Using CPANMinus
 #
 cpanm Task::WebDyne::PAGI

=head1 DESCRIPTION

Task::WebDyne::PAGI installs the Perl modules required to use PAGI with
WebDyne.


=head1 AUTHOR

Andrew Speer L<mailto:andrew.speer@isolutions.com.au>


=head1 LICENSE and COPYRIGHT

This file is part of Task::WebDyne::PAGI.

This software is copyright (c) 2026 by Andrew Speer L<mailto:andrew.speer@isolutions.com.au>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

Full license text is available at:

L<http://dev.perl.org/licenses/>
